# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetMemberRoleResult',
    'AwaitableGetMemberRoleResult',
    'get_member_role',
    'get_member_role_output',
]

@pulumi.output_type
class GetMemberRoleResult:
    """
    A collection of values returned by getMemberRole.
    """
    def __init__(__self__, base_access_level=None, created_at=None, description=None, edit_path=None, enabled_permissions=None, id=None, iid=None, name=None):
        if base_access_level and not isinstance(base_access_level, str):
            raise TypeError("Expected argument 'base_access_level' to be a str")
        pulumi.set(__self__, "base_access_level", base_access_level)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if edit_path and not isinstance(edit_path, str):
            raise TypeError("Expected argument 'edit_path' to be a str")
        pulumi.set(__self__, "edit_path", edit_path)
        if enabled_permissions and not isinstance(enabled_permissions, list):
            raise TypeError("Expected argument 'enabled_permissions' to be a list")
        pulumi.set(__self__, "enabled_permissions", enabled_permissions)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if iid and not isinstance(iid, int):
            raise TypeError("Expected argument 'iid' to be a int")
        pulumi.set(__self__, "iid", iid)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="baseAccessLevel")
    def base_access_level(self) -> _builtins.str:
        """
        The base access level of the custom role.
        """
        return pulumi.get(self, "base_access_level")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        Timestamp of when the member role was created.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the member role.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="editPath")
    def edit_path(self) -> _builtins.str:
        """
        The Web UI path to edit the member role
        """
        return pulumi.get(self, "edit_path")

    @_builtins.property
    @pulumi.getter(name="enabledPermissions")
    def enabled_permissions(self) -> Sequence[_builtins.str]:
        """
        All permissions enabled for the custom role.
        """
        return pulumi.get(self, "enabled_permissions")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        Globally unique ID of the member role. In the format of `gid://gitlab/MemberRole/1`
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def iid(self) -> _builtins.int:
        """
        The member role ID integer value extracted from the `id` attribute
        """
        return pulumi.get(self, "iid")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the member role.
        """
        return pulumi.get(self, "name")


class AwaitableGetMemberRoleResult(GetMemberRoleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMemberRoleResult(
            base_access_level=self.base_access_level,
            created_at=self.created_at,
            description=self.description,
            edit_path=self.edit_path,
            enabled_permissions=self.enabled_permissions,
            id=self.id,
            iid=self.iid,
            name=self.name)


def get_member_role(id: Optional[_builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMemberRoleResult:
    """
    The `MemberRole` data source allows details of a custom member role to be retrieved.

    **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/api/graphql/reference/#querymemberrole)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_member_role(id="gid://gitlab/MemberRole/1")
    ```


    :param _builtins.str id: Globally unique ID of the member role. In the format of `gid://gitlab/MemberRole/1`
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getMemberRole:getMemberRole', __args__, opts=opts, typ=GetMemberRoleResult).value

    return AwaitableGetMemberRoleResult(
        base_access_level=pulumi.get(__ret__, 'base_access_level'),
        created_at=pulumi.get(__ret__, 'created_at'),
        description=pulumi.get(__ret__, 'description'),
        edit_path=pulumi.get(__ret__, 'edit_path'),
        enabled_permissions=pulumi.get(__ret__, 'enabled_permissions'),
        id=pulumi.get(__ret__, 'id'),
        iid=pulumi.get(__ret__, 'iid'),
        name=pulumi.get(__ret__, 'name'))
def get_member_role_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetMemberRoleResult]:
    """
    The `MemberRole` data source allows details of a custom member role to be retrieved.

    **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/api/graphql/reference/#querymemberrole)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_member_role(id="gid://gitlab/MemberRole/1")
    ```


    :param _builtins.str id: Globally unique ID of the member role. In the format of `gid://gitlab/MemberRole/1`
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getMemberRole:getMemberRole', __args__, opts=opts, typ=GetMemberRoleResult)
    return __ret__.apply(lambda __response__: GetMemberRoleResult(
        base_access_level=pulumi.get(__response__, 'base_access_level'),
        created_at=pulumi.get(__response__, 'created_at'),
        description=pulumi.get(__response__, 'description'),
        edit_path=pulumi.get(__response__, 'edit_path'),
        enabled_permissions=pulumi.get(__response__, 'enabled_permissions'),
        id=pulumi.get(__response__, 'id'),
        iid=pulumi.get(__response__, 'iid'),
        name=pulumi.get(__response__, 'name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('gitlab')


class _ExportableConfig(types.ModuleType):
    @_builtins.property
    def base_url(self) -> Optional[str]:
        """
        This is the target GitLab base API endpoint. Providing a value is a requirement when working with GitLab CE or GitLab Enterprise e.g. `https://my.gitlab.server/api/v4/`. It is optional to provide this value and it can also be sourced from the `GITLAB_BASE_URL` environment variable. The value must end with a slash.
        """
        return __config__.get('baseUrl')

    @_builtins.property
    def cacert_file(self) -> Optional[str]:
        """
        This is a file containing the ca cert to verify the gitlab instance. This is available for use when working with GitLab CE or Gitlab Enterprise with a locally-issued or self-signed certificate chain.
        """
        return __config__.get('cacertFile')

    @_builtins.property
    def client_cert(self) -> Optional[str]:
        """
        File path to client certificate when GitLab instance is behind company proxy. File must contain PEM encoded data.
        """
        return __config__.get('clientCert')

    @_builtins.property
    def client_key(self) -> Optional[str]:
        """
        File path to client key when GitLab instance is behind company proxy. File must contain PEM encoded data. Required when `client_cert` is set.
        """
        return __config__.get('clientKey')

    @_builtins.property
    def config_file(self) -> Optional[str]:
        """
        The path to the configuration file to use. It may be sourced from the `GITLAB_CONFIG_FILE` environment variable.
        """
        return __config__.get('configFile')

    @_builtins.property
    def context(self) -> Optional[str]:
        """
        The context to use for authentication and configuration. The context must exist in the configuration file. It may be sourced from the `GITLAB_CONTEXT` environment variable.
        """
        return __config__.get('context')

    @_builtins.property
    def early_auth_check(self) -> Optional[bool]:
        return __config__.get_bool('earlyAuthCheck')

    @_builtins.property
    def enable_auto_ci_support(self) -> Optional[bool]:
        """
        If automatic CI support should be enabled or not. This only works when not providing a token.
        """
        return __config__.get_bool('enableAutoCiSupport')

    @_builtins.property
    def headers(self) -> Optional[str]:
        """
        A map of headers to append to all API request to the GitLab instance.
        """
        return __config__.get('headers')

    @_builtins.property
    def insecure(self) -> Optional[bool]:
        """
        When set to true this disables SSL verification of the connection to the GitLab instance.
        """
        return __config__.get_bool('insecure')

    @_builtins.property
    def retries(self) -> Optional[int]:
        """
        The number of retries to execute when receiving a 429 Rate Limit error. Each retry will exponentially back off.
        """
        return __config__.get_int('retries')

    @_builtins.property
    def token(self) -> Optional[str]:
        """
        The OAuth2 Token, Project, Group, Personal Access Token or CI Job Token used to connect to GitLab. The OAuth method is used in this provider for authentication (using Bearer authorization token). See https://docs.gitlab.com/api/#authentication for details. It may be sourced from the `GITLAB_TOKEN` environment variable.
        """
        return __config__.get('token')




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetGroupsResult',
    'AwaitableGetGroupsResult',
    'get_groups',
    'get_groups_output',
]

@pulumi.output_type
class GetGroupsResult:
    """
    A collection of values returned by getGroups.
    """
    def __init__(__self__, groups=None, id=None, order_by=None, search=None, sort=None, top_level_only=None):
        if groups and not isinstance(groups, list):
            raise TypeError("Expected argument 'groups' to be a list")
        pulumi.set(__self__, "groups", groups)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if order_by and not isinstance(order_by, str):
            raise TypeError("Expected argument 'order_by' to be a str")
        pulumi.set(__self__, "order_by", order_by)
        if search and not isinstance(search, str):
            raise TypeError("Expected argument 'search' to be a str")
        pulumi.set(__self__, "search", search)
        if sort and not isinstance(sort, str):
            raise TypeError("Expected argument 'sort' to be a str")
        pulumi.set(__self__, "sort", sort)
        if top_level_only and not isinstance(top_level_only, bool):
            raise TypeError("Expected argument 'top_level_only' to be a bool")
        pulumi.set(__self__, "top_level_only", top_level_only)

    @_builtins.property
    @pulumi.getter
    def groups(self) -> Sequence['outputs.GetGroupsGroupResult']:
        """
        The list of groups.
        """
        return pulumi.get(self, "groups")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of this datasource. In the format of a hash of the provided search attributes.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="orderBy")
    def order_by(self) -> Optional[_builtins.str]:
        """
        Order the groups' list by `id`, `name`, `path`, or `similarity`. (Requires administrator privileges)
        """
        return pulumi.get(self, "order_by")

    @_builtins.property
    @pulumi.getter
    def search(self) -> Optional[_builtins.str]:
        """
        Search groups by name or path.
        """
        return pulumi.get(self, "search")

    @_builtins.property
    @pulumi.getter
    def sort(self) -> Optional[_builtins.str]:
        """
        Sort groups' list in asc or desc order. (Requires administrator privileges)
        """
        return pulumi.get(self, "sort")

    @_builtins.property
    @pulumi.getter(name="topLevelOnly")
    def top_level_only(self) -> Optional[_builtins.bool]:
        """
        Limit to top level groups, excluding all subgroups.
        """
        return pulumi.get(self, "top_level_only")


class AwaitableGetGroupsResult(GetGroupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupsResult(
            groups=self.groups,
            id=self.id,
            order_by=self.order_by,
            search=self.search,
            sort=self.sort,
            top_level_only=self.top_level_only)


def get_groups(order_by: Optional[_builtins.str] = None,
               search: Optional[_builtins.str] = None,
               sort: Optional[_builtins.str] = None,
               top_level_only: Optional[_builtins.bool] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGroupsResult:
    """
    The `get_groups` data source allows details of multiple groups to be retrieved given some optional filter criteria.

    > Some attributes might not be returned depending on if you're an admin or not.

    > Some available options require administrator privileges.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/groups/#list-groups)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_groups(sort="desc",
        order_by="name")
    example_two = gitlab.get_groups(search="GitLab")
    ```


    :param _builtins.str order_by: Order the groups' list by `id`, `name`, `path`, or `similarity`. (Requires administrator privileges)
    :param _builtins.str search: Search groups by name or path.
    :param _builtins.str sort: Sort groups' list in asc or desc order. (Requires administrator privileges)
    :param _builtins.bool top_level_only: Limit to top level groups, excluding all subgroups.
    """
    __args__ = dict()
    __args__['orderBy'] = order_by
    __args__['search'] = search
    __args__['sort'] = sort
    __args__['topLevelOnly'] = top_level_only
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getGroups:getGroups', __args__, opts=opts, typ=GetGroupsResult).value

    return AwaitableGetGroupsResult(
        groups=pulumi.get(__ret__, 'groups'),
        id=pulumi.get(__ret__, 'id'),
        order_by=pulumi.get(__ret__, 'order_by'),
        search=pulumi.get(__ret__, 'search'),
        sort=pulumi.get(__ret__, 'sort'),
        top_level_only=pulumi.get(__ret__, 'top_level_only'))
def get_groups_output(order_by: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      search: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      sort: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      top_level_only: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGroupsResult]:
    """
    The `get_groups` data source allows details of multiple groups to be retrieved given some optional filter criteria.

    > Some attributes might not be returned depending on if you're an admin or not.

    > Some available options require administrator privileges.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/groups/#list-groups)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_groups(sort="desc",
        order_by="name")
    example_two = gitlab.get_groups(search="GitLab")
    ```


    :param _builtins.str order_by: Order the groups' list by `id`, `name`, `path`, or `similarity`. (Requires administrator privileges)
    :param _builtins.str search: Search groups by name or path.
    :param _builtins.str sort: Sort groups' list in asc or desc order. (Requires administrator privileges)
    :param _builtins.bool top_level_only: Limit to top level groups, excluding all subgroups.
    """
    __args__ = dict()
    __args__['orderBy'] = order_by
    __args__['search'] = search
    __args__['sort'] = sort
    __args__['topLevelOnly'] = top_level_only
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getGroups:getGroups', __args__, opts=opts, typ=GetGroupsResult)
    return __ret__.apply(lambda __response__: GetGroupsResult(
        groups=pulumi.get(__response__, 'groups'),
        id=pulumi.get(__response__, 'id'),
        order_by=pulumi.get(__response__, 'order_by'),
        search=pulumi.get(__response__, 'search'),
        sort=pulumi.get(__response__, 'sort'),
        top_level_only=pulumi.get(__response__, 'top_level_only')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetGroupSubgroupsResult',
    'AwaitableGetGroupSubgroupsResult',
    'get_group_subgroups',
    'get_group_subgroups_output',
]

@pulumi.output_type
class GetGroupSubgroupsResult:
    """
    A collection of values returned by getGroupSubgroups.
    """
    def __init__(__self__, all_available=None, group_id=None, id=None, min_access_level=None, order_by=None, owned=None, search=None, skip_groups=None, sort=None, statistics=None, subgroups=None, with_custom_attributes=None):
        if all_available and not isinstance(all_available, bool):
            raise TypeError("Expected argument 'all_available' to be a bool")
        pulumi.set(__self__, "all_available", all_available)
        if group_id and not isinstance(group_id, int):
            raise TypeError("Expected argument 'group_id' to be a int")
        pulumi.set(__self__, "group_id", group_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if min_access_level and not isinstance(min_access_level, str):
            raise TypeError("Expected argument 'min_access_level' to be a str")
        pulumi.set(__self__, "min_access_level", min_access_level)
        if order_by and not isinstance(order_by, str):
            raise TypeError("Expected argument 'order_by' to be a str")
        pulumi.set(__self__, "order_by", order_by)
        if owned and not isinstance(owned, bool):
            raise TypeError("Expected argument 'owned' to be a bool")
        pulumi.set(__self__, "owned", owned)
        if search and not isinstance(search, str):
            raise TypeError("Expected argument 'search' to be a str")
        pulumi.set(__self__, "search", search)
        if skip_groups and not isinstance(skip_groups, list):
            raise TypeError("Expected argument 'skip_groups' to be a list")
        pulumi.set(__self__, "skip_groups", skip_groups)
        if sort and not isinstance(sort, str):
            raise TypeError("Expected argument 'sort' to be a str")
        pulumi.set(__self__, "sort", sort)
        if statistics and not isinstance(statistics, bool):
            raise TypeError("Expected argument 'statistics' to be a bool")
        pulumi.set(__self__, "statistics", statistics)
        if subgroups and not isinstance(subgroups, list):
            raise TypeError("Expected argument 'subgroups' to be a list")
        pulumi.set(__self__, "subgroups", subgroups)
        if with_custom_attributes and not isinstance(with_custom_attributes, bool):
            raise TypeError("Expected argument 'with_custom_attributes' to be a bool")
        pulumi.set(__self__, "with_custom_attributes", with_custom_attributes)

    @_builtins.property
    @pulumi.getter(name="allAvailable")
    def all_available(self) -> _builtins.bool:
        """
        Show all the groups you have access to.
        """
        return pulumi.get(self, "all_available")

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> _builtins.int:
        """
        The ID of the group.
        """
        return pulumi.get(self, "group_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of this datasource. In the format `<group-id>`.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="minAccessLevel")
    def min_access_level(self) -> _builtins.str:
        """
        Limit to groups where current user has at least this access level.
        """
        return pulumi.get(self, "min_access_level")

    @_builtins.property
    @pulumi.getter(name="orderBy")
    def order_by(self) -> _builtins.str:
        """
        Order groups by name, path or id.
        """
        return pulumi.get(self, "order_by")

    @_builtins.property
    @pulumi.getter
    def owned(self) -> _builtins.bool:
        """
        Limit to groups explicitly owned by the current user.
        """
        return pulumi.get(self, "owned")

    @_builtins.property
    @pulumi.getter
    def search(self) -> _builtins.str:
        """
        Return the list of authorized groups matching the search criteria.
        """
        return pulumi.get(self, "search")

    @_builtins.property
    @pulumi.getter(name="skipGroups")
    def skip_groups(self) -> Sequence[_builtins.int]:
        """
        Skip the group IDs passed.
        """
        return pulumi.get(self, "skip_groups")

    @_builtins.property
    @pulumi.getter
    def sort(self) -> _builtins.str:
        """
        Order groups in asc or desc order.
        """
        return pulumi.get(self, "sort")

    @_builtins.property
    @pulumi.getter
    def statistics(self) -> _builtins.bool:
        """
        Include group statistics (administrators only).
        """
        return pulumi.get(self, "statistics")

    @_builtins.property
    @pulumi.getter
    def subgroups(self) -> Sequence['outputs.GetGroupSubgroupsSubgroupResult']:
        """
        Subgroups of the parent group.
        """
        return pulumi.get(self, "subgroups")

    @_builtins.property
    @pulumi.getter(name="withCustomAttributes")
    def with_custom_attributes(self) -> _builtins.bool:
        """
        Include custom attributes in response (administrators only).
        """
        return pulumi.get(self, "with_custom_attributes")


class AwaitableGetGroupSubgroupsResult(GetGroupSubgroupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupSubgroupsResult(
            all_available=self.all_available,
            group_id=self.group_id,
            id=self.id,
            min_access_level=self.min_access_level,
            order_by=self.order_by,
            owned=self.owned,
            search=self.search,
            skip_groups=self.skip_groups,
            sort=self.sort,
            statistics=self.statistics,
            subgroups=self.subgroups,
            with_custom_attributes=self.with_custom_attributes)


def get_group_subgroups(all_available: Optional[_builtins.bool] = None,
                        group_id: Optional[_builtins.int] = None,
                        min_access_level: Optional[_builtins.str] = None,
                        order_by: Optional[_builtins.str] = None,
                        owned: Optional[_builtins.bool] = None,
                        search: Optional[_builtins.str] = None,
                        skip_groups: Optional[Sequence[_builtins.int]] = None,
                        sort: Optional[_builtins.str] = None,
                        statistics: Optional[_builtins.bool] = None,
                        with_custom_attributes: Optional[_builtins.bool] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGroupSubgroupsResult:
    """
    The `get_group_subgroups` data source allows to get subgroups of a group.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/groups/#list-subgroups)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    subgroups = gitlab.get_group_subgroups(group_id=123456)
    pulumi.export("subgroups", subgroups)
    ```


    :param _builtins.bool all_available: Show all the groups you have access to.
    :param _builtins.int group_id: The ID of the group.
    :param _builtins.str min_access_level: Limit to groups where current user has at least this access level.
    :param _builtins.str order_by: Order groups by name, path or id.
    :param _builtins.bool owned: Limit to groups explicitly owned by the current user.
    :param _builtins.str search: Return the list of authorized groups matching the search criteria.
    :param Sequence[_builtins.int] skip_groups: Skip the group IDs passed.
    :param _builtins.str sort: Order groups in asc or desc order.
    :param _builtins.bool statistics: Include group statistics (administrators only).
    :param _builtins.bool with_custom_attributes: Include custom attributes in response (administrators only).
    """
    __args__ = dict()
    __args__['allAvailable'] = all_available
    __args__['groupId'] = group_id
    __args__['minAccessLevel'] = min_access_level
    __args__['orderBy'] = order_by
    __args__['owned'] = owned
    __args__['search'] = search
    __args__['skipGroups'] = skip_groups
    __args__['sort'] = sort
    __args__['statistics'] = statistics
    __args__['withCustomAttributes'] = with_custom_attributes
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getGroupSubgroups:getGroupSubgroups', __args__, opts=opts, typ=GetGroupSubgroupsResult).value

    return AwaitableGetGroupSubgroupsResult(
        all_available=pulumi.get(__ret__, 'all_available'),
        group_id=pulumi.get(__ret__, 'group_id'),
        id=pulumi.get(__ret__, 'id'),
        min_access_level=pulumi.get(__ret__, 'min_access_level'),
        order_by=pulumi.get(__ret__, 'order_by'),
        owned=pulumi.get(__ret__, 'owned'),
        search=pulumi.get(__ret__, 'search'),
        skip_groups=pulumi.get(__ret__, 'skip_groups'),
        sort=pulumi.get(__ret__, 'sort'),
        statistics=pulumi.get(__ret__, 'statistics'),
        subgroups=pulumi.get(__ret__, 'subgroups'),
        with_custom_attributes=pulumi.get(__ret__, 'with_custom_attributes'))
def get_group_subgroups_output(all_available: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                               group_id: Optional[pulumi.Input[_builtins.int]] = None,
                               min_access_level: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               order_by: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               owned: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                               search: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               skip_groups: Optional[pulumi.Input[Optional[Sequence[_builtins.int]]]] = None,
                               sort: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               statistics: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                               with_custom_attributes: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGroupSubgroupsResult]:
    """
    The `get_group_subgroups` data source allows to get subgroups of a group.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/groups/#list-subgroups)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    subgroups = gitlab.get_group_subgroups(group_id=123456)
    pulumi.export("subgroups", subgroups)
    ```


    :param _builtins.bool all_available: Show all the groups you have access to.
    :param _builtins.int group_id: The ID of the group.
    :param _builtins.str min_access_level: Limit to groups where current user has at least this access level.
    :param _builtins.str order_by: Order groups by name, path or id.
    :param _builtins.bool owned: Limit to groups explicitly owned by the current user.
    :param _builtins.str search: Return the list of authorized groups matching the search criteria.
    :param Sequence[_builtins.int] skip_groups: Skip the group IDs passed.
    :param _builtins.str sort: Order groups in asc or desc order.
    :param _builtins.bool statistics: Include group statistics (administrators only).
    :param _builtins.bool with_custom_attributes: Include custom attributes in response (administrators only).
    """
    __args__ = dict()
    __args__['allAvailable'] = all_available
    __args__['groupId'] = group_id
    __args__['minAccessLevel'] = min_access_level
    __args__['orderBy'] = order_by
    __args__['owned'] = owned
    __args__['search'] = search
    __args__['skipGroups'] = skip_groups
    __args__['sort'] = sort
    __args__['statistics'] = statistics
    __args__['withCustomAttributes'] = with_custom_attributes
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getGroupSubgroups:getGroupSubgroups', __args__, opts=opts, typ=GetGroupSubgroupsResult)
    return __ret__.apply(lambda __response__: GetGroupSubgroupsResult(
        all_available=pulumi.get(__response__, 'all_available'),
        group_id=pulumi.get(__response__, 'group_id'),
        id=pulumi.get(__response__, 'id'),
        min_access_level=pulumi.get(__response__, 'min_access_level'),
        order_by=pulumi.get(__response__, 'order_by'),
        owned=pulumi.get(__response__, 'owned'),
        search=pulumi.get(__response__, 'search'),
        skip_groups=pulumi.get(__response__, 'skip_groups'),
        sort=pulumi.get(__response__, 'sort'),
        statistics=pulumi.get(__response__, 'statistics'),
        subgroups=pulumi.get(__response__, 'subgroups'),
        with_custom_attributes=pulumi.get(__response__, 'with_custom_attributes')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['GroupLevelMrApprovalsArgs', 'GroupLevelMrApprovals']

@pulumi.input_type
class GroupLevelMrApprovalsArgs:
    def __init__(__self__, *,
                 group: pulumi.Input[_builtins.str],
                 allow_author_approval: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_committer_approval: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_overrides_to_approver_list_per_merge_request: Optional[pulumi.Input[_builtins.bool]] = None,
                 keep_settings_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_reauthentication_to_approve: Optional[pulumi.Input[_builtins.bool]] = None,
                 retain_approvals_on_push: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a GroupLevelMrApprovals resource.
        :param pulumi.Input[_builtins.str] group: The ID or URL-encoded path of the group.
        :param pulumi.Input[_builtins.bool] allow_author_approval: Allow or prevent authors from self approving merge requests; `true` means authors can self approve.
        :param pulumi.Input[_builtins.bool] allow_committer_approval: Allow or prevent committers from self approving merge requests.
        :param pulumi.Input[_builtins.bool] allow_overrides_to_approver_list_per_merge_request: Allow or prevent overriding approvers per merge request.
        :param pulumi.Input[_builtins.bool] require_reauthentication_to_approve: Require approver to authenticate before adding the approval.
        :param pulumi.Input[_builtins.bool] retain_approvals_on_push: Retain approval count on a new push.
        """
        pulumi.set(__self__, "group", group)
        if allow_author_approval is not None:
            pulumi.set(__self__, "allow_author_approval", allow_author_approval)
        if allow_committer_approval is not None:
            pulumi.set(__self__, "allow_committer_approval", allow_committer_approval)
        if allow_overrides_to_approver_list_per_merge_request is not None:
            pulumi.set(__self__, "allow_overrides_to_approver_list_per_merge_request", allow_overrides_to_approver_list_per_merge_request)
        if keep_settings_on_destroy is not None:
            pulumi.set(__self__, "keep_settings_on_destroy", keep_settings_on_destroy)
        if require_reauthentication_to_approve is not None:
            pulumi.set(__self__, "require_reauthentication_to_approve", require_reauthentication_to_approve)
        if retain_approvals_on_push is not None:
            pulumi.set(__self__, "retain_approvals_on_push", retain_approvals_on_push)

    @_builtins.property
    @pulumi.getter
    def group(self) -> pulumi.Input[_builtins.str]:
        """
        The ID or URL-encoded path of the group.
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "group", value)

    @_builtins.property
    @pulumi.getter(name="allowAuthorApproval")
    def allow_author_approval(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow or prevent authors from self approving merge requests; `true` means authors can self approve.
        """
        return pulumi.get(self, "allow_author_approval")

    @allow_author_approval.setter
    def allow_author_approval(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_author_approval", value)

    @_builtins.property
    @pulumi.getter(name="allowCommitterApproval")
    def allow_committer_approval(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow or prevent committers from self approving merge requests.
        """
        return pulumi.get(self, "allow_committer_approval")

    @allow_committer_approval.setter
    def allow_committer_approval(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_committer_approval", value)

    @_builtins.property
    @pulumi.getter(name="allowOverridesToApproverListPerMergeRequest")
    def allow_overrides_to_approver_list_per_merge_request(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow or prevent overriding approvers per merge request.
        """
        return pulumi.get(self, "allow_overrides_to_approver_list_per_merge_request")

    @allow_overrides_to_approver_list_per_merge_request.setter
    def allow_overrides_to_approver_list_per_merge_request(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_overrides_to_approver_list_per_merge_request", value)

    @_builtins.property
    @pulumi.getter(name="keepSettingsOnDestroy")
    def keep_settings_on_destroy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "keep_settings_on_destroy")

    @keep_settings_on_destroy.setter
    def keep_settings_on_destroy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "keep_settings_on_destroy", value)

    @_builtins.property
    @pulumi.getter(name="requireReauthenticationToApprove")
    def require_reauthentication_to_approve(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Require approver to authenticate before adding the approval.
        """
        return pulumi.get(self, "require_reauthentication_to_approve")

    @require_reauthentication_to_approve.setter
    def require_reauthentication_to_approve(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "require_reauthentication_to_approve", value)

    @_builtins.property
    @pulumi.getter(name="retainApprovalsOnPush")
    def retain_approvals_on_push(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Retain approval count on a new push.
        """
        return pulumi.get(self, "retain_approvals_on_push")

    @retain_approvals_on_push.setter
    def retain_approvals_on_push(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "retain_approvals_on_push", value)


@pulumi.input_type
class _GroupLevelMrApprovalsState:
    def __init__(__self__, *,
                 allow_author_approval: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_committer_approval: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_overrides_to_approver_list_per_merge_request: Optional[pulumi.Input[_builtins.bool]] = None,
                 group: Optional[pulumi.Input[_builtins.str]] = None,
                 keep_settings_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_reauthentication_to_approve: Optional[pulumi.Input[_builtins.bool]] = None,
                 retain_approvals_on_push: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering GroupLevelMrApprovals resources.
        :param pulumi.Input[_builtins.bool] allow_author_approval: Allow or prevent authors from self approving merge requests; `true` means authors can self approve.
        :param pulumi.Input[_builtins.bool] allow_committer_approval: Allow or prevent committers from self approving merge requests.
        :param pulumi.Input[_builtins.bool] allow_overrides_to_approver_list_per_merge_request: Allow or prevent overriding approvers per merge request.
        :param pulumi.Input[_builtins.str] group: The ID or URL-encoded path of the group.
        :param pulumi.Input[_builtins.bool] require_reauthentication_to_approve: Require approver to authenticate before adding the approval.
        :param pulumi.Input[_builtins.bool] retain_approvals_on_push: Retain approval count on a new push.
        """
        if allow_author_approval is not None:
            pulumi.set(__self__, "allow_author_approval", allow_author_approval)
        if allow_committer_approval is not None:
            pulumi.set(__self__, "allow_committer_approval", allow_committer_approval)
        if allow_overrides_to_approver_list_per_merge_request is not None:
            pulumi.set(__self__, "allow_overrides_to_approver_list_per_merge_request", allow_overrides_to_approver_list_per_merge_request)
        if group is not None:
            pulumi.set(__self__, "group", group)
        if keep_settings_on_destroy is not None:
            pulumi.set(__self__, "keep_settings_on_destroy", keep_settings_on_destroy)
        if require_reauthentication_to_approve is not None:
            pulumi.set(__self__, "require_reauthentication_to_approve", require_reauthentication_to_approve)
        if retain_approvals_on_push is not None:
            pulumi.set(__self__, "retain_approvals_on_push", retain_approvals_on_push)

    @_builtins.property
    @pulumi.getter(name="allowAuthorApproval")
    def allow_author_approval(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow or prevent authors from self approving merge requests; `true` means authors can self approve.
        """
        return pulumi.get(self, "allow_author_approval")

    @allow_author_approval.setter
    def allow_author_approval(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_author_approval", value)

    @_builtins.property
    @pulumi.getter(name="allowCommitterApproval")
    def allow_committer_approval(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow or prevent committers from self approving merge requests.
        """
        return pulumi.get(self, "allow_committer_approval")

    @allow_committer_approval.setter
    def allow_committer_approval(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_committer_approval", value)

    @_builtins.property
    @pulumi.getter(name="allowOverridesToApproverListPerMergeRequest")
    def allow_overrides_to_approver_list_per_merge_request(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow or prevent overriding approvers per merge request.
        """
        return pulumi.get(self, "allow_overrides_to_approver_list_per_merge_request")

    @allow_overrides_to_approver_list_per_merge_request.setter
    def allow_overrides_to_approver_list_per_merge_request(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_overrides_to_approver_list_per_merge_request", value)

    @_builtins.property
    @pulumi.getter
    def group(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID or URL-encoded path of the group.
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "group", value)

    @_builtins.property
    @pulumi.getter(name="keepSettingsOnDestroy")
    def keep_settings_on_destroy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "keep_settings_on_destroy")

    @keep_settings_on_destroy.setter
    def keep_settings_on_destroy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "keep_settings_on_destroy", value)

    @_builtins.property
    @pulumi.getter(name="requireReauthenticationToApprove")
    def require_reauthentication_to_approve(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Require approver to authenticate before adding the approval.
        """
        return pulumi.get(self, "require_reauthentication_to_approve")

    @require_reauthentication_to_approve.setter
    def require_reauthentication_to_approve(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "require_reauthentication_to_approve", value)

    @_builtins.property
    @pulumi.getter(name="retainApprovalsOnPush")
    def retain_approvals_on_push(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Retain approval count on a new push.
        """
        return pulumi.get(self, "retain_approvals_on_push")

    @retain_approvals_on_push.setter
    def retain_approvals_on_push(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "retain_approvals_on_push", value)


@pulumi.type_token("gitlab:index/groupLevelMrApprovals:GroupLevelMrApprovals")
class GroupLevelMrApprovals(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_author_approval: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_committer_approval: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_overrides_to_approver_list_per_merge_request: Optional[pulumi.Input[_builtins.bool]] = None,
                 group: Optional[pulumi.Input[_builtins.str]] = None,
                 keep_settings_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_reauthentication_to_approve: Optional[pulumi.Input[_builtins.bool]] = None,
                 retain_approvals_on_push: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        foo = gitlab.Group("foo",
            name="test_group",
            path="test_group",
            description="An example group")
        foo_group_level_mr_approvals = gitlab.GroupLevelMrApprovals("foo",
            group=foo.id,
            allow_author_approval=True,
            allow_committer_approval=True,
            allow_overrides_to_approver_list_per_merge_request=True,
            retain_approvals_on_push=True,
            selective_code_owner_removals=False,
            require_reauthentication_to_approve=True)
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_group_level_mr_approvals`. For example:

        terraform

        import {

          to = gitlab_group_level_mr_approvals.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        ```sh
        $ pulumi import gitlab:index/groupLevelMrApprovals:GroupLevelMrApprovals You can import an approval configuration state using `<resource> <group_id>`.
        ```

        For example:

        ```sh
        $ pulumi import gitlab:index/groupLevelMrApprovals:GroupLevelMrApprovals foo 1234
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] allow_author_approval: Allow or prevent authors from self approving merge requests; `true` means authors can self approve.
        :param pulumi.Input[_builtins.bool] allow_committer_approval: Allow or prevent committers from self approving merge requests.
        :param pulumi.Input[_builtins.bool] allow_overrides_to_approver_list_per_merge_request: Allow or prevent overriding approvers per merge request.
        :param pulumi.Input[_builtins.str] group: The ID or URL-encoded path of the group.
        :param pulumi.Input[_builtins.bool] require_reauthentication_to_approve: Require approver to authenticate before adding the approval.
        :param pulumi.Input[_builtins.bool] retain_approvals_on_push: Retain approval count on a new push.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupLevelMrApprovalsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        foo = gitlab.Group("foo",
            name="test_group",
            path="test_group",
            description="An example group")
        foo_group_level_mr_approvals = gitlab.GroupLevelMrApprovals("foo",
            group=foo.id,
            allow_author_approval=True,
            allow_committer_approval=True,
            allow_overrides_to_approver_list_per_merge_request=True,
            retain_approvals_on_push=True,
            selective_code_owner_removals=False,
            require_reauthentication_to_approve=True)
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_group_level_mr_approvals`. For example:

        terraform

        import {

          to = gitlab_group_level_mr_approvals.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        ```sh
        $ pulumi import gitlab:index/groupLevelMrApprovals:GroupLevelMrApprovals You can import an approval configuration state using `<resource> <group_id>`.
        ```

        For example:

        ```sh
        $ pulumi import gitlab:index/groupLevelMrApprovals:GroupLevelMrApprovals foo 1234
        ```

        :param str resource_name: The name of the resource.
        :param GroupLevelMrApprovalsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupLevelMrApprovalsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_author_approval: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_committer_approval: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_overrides_to_approver_list_per_merge_request: Optional[pulumi.Input[_builtins.bool]] = None,
                 group: Optional[pulumi.Input[_builtins.str]] = None,
                 keep_settings_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_reauthentication_to_approve: Optional[pulumi.Input[_builtins.bool]] = None,
                 retain_approvals_on_push: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupLevelMrApprovalsArgs.__new__(GroupLevelMrApprovalsArgs)

            __props__.__dict__["allow_author_approval"] = allow_author_approval
            __props__.__dict__["allow_committer_approval"] = allow_committer_approval
            __props__.__dict__["allow_overrides_to_approver_list_per_merge_request"] = allow_overrides_to_approver_list_per_merge_request
            if group is None and not opts.urn:
                raise TypeError("Missing required property 'group'")
            __props__.__dict__["group"] = group
            __props__.__dict__["keep_settings_on_destroy"] = keep_settings_on_destroy
            __props__.__dict__["require_reauthentication_to_approve"] = require_reauthentication_to_approve
            __props__.__dict__["retain_approvals_on_push"] = retain_approvals_on_push
        super(GroupLevelMrApprovals, __self__).__init__(
            'gitlab:index/groupLevelMrApprovals:GroupLevelMrApprovals',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allow_author_approval: Optional[pulumi.Input[_builtins.bool]] = None,
            allow_committer_approval: Optional[pulumi.Input[_builtins.bool]] = None,
            allow_overrides_to_approver_list_per_merge_request: Optional[pulumi.Input[_builtins.bool]] = None,
            group: Optional[pulumi.Input[_builtins.str]] = None,
            keep_settings_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
            require_reauthentication_to_approve: Optional[pulumi.Input[_builtins.bool]] = None,
            retain_approvals_on_push: Optional[pulumi.Input[_builtins.bool]] = None) -> 'GroupLevelMrApprovals':
        """
        Get an existing GroupLevelMrApprovals resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] allow_author_approval: Allow or prevent authors from self approving merge requests; `true` means authors can self approve.
        :param pulumi.Input[_builtins.bool] allow_committer_approval: Allow or prevent committers from self approving merge requests.
        :param pulumi.Input[_builtins.bool] allow_overrides_to_approver_list_per_merge_request: Allow or prevent overriding approvers per merge request.
        :param pulumi.Input[_builtins.str] group: The ID or URL-encoded path of the group.
        :param pulumi.Input[_builtins.bool] require_reauthentication_to_approve: Require approver to authenticate before adding the approval.
        :param pulumi.Input[_builtins.bool] retain_approvals_on_push: Retain approval count on a new push.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupLevelMrApprovalsState.__new__(_GroupLevelMrApprovalsState)

        __props__.__dict__["allow_author_approval"] = allow_author_approval
        __props__.__dict__["allow_committer_approval"] = allow_committer_approval
        __props__.__dict__["allow_overrides_to_approver_list_per_merge_request"] = allow_overrides_to_approver_list_per_merge_request
        __props__.__dict__["group"] = group
        __props__.__dict__["keep_settings_on_destroy"] = keep_settings_on_destroy
        __props__.__dict__["require_reauthentication_to_approve"] = require_reauthentication_to_approve
        __props__.__dict__["retain_approvals_on_push"] = retain_approvals_on_push
        return GroupLevelMrApprovals(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="allowAuthorApproval")
    def allow_author_approval(self) -> pulumi.Output[_builtins.bool]:
        """
        Allow or prevent authors from self approving merge requests; `true` means authors can self approve.
        """
        return pulumi.get(self, "allow_author_approval")

    @_builtins.property
    @pulumi.getter(name="allowCommitterApproval")
    def allow_committer_approval(self) -> pulumi.Output[_builtins.bool]:
        """
        Allow or prevent committers from self approving merge requests.
        """
        return pulumi.get(self, "allow_committer_approval")

    @_builtins.property
    @pulumi.getter(name="allowOverridesToApproverListPerMergeRequest")
    def allow_overrides_to_approver_list_per_merge_request(self) -> pulumi.Output[_builtins.bool]:
        """
        Allow or prevent overriding approvers per merge request.
        """
        return pulumi.get(self, "allow_overrides_to_approver_list_per_merge_request")

    @_builtins.property
    @pulumi.getter
    def group(self) -> pulumi.Output[_builtins.str]:
        """
        The ID or URL-encoded path of the group.
        """
        return pulumi.get(self, "group")

    @_builtins.property
    @pulumi.getter(name="keepSettingsOnDestroy")
    def keep_settings_on_destroy(self) -> pulumi.Output[_builtins.bool]:
        return pulumi.get(self, "keep_settings_on_destroy")

    @_builtins.property
    @pulumi.getter(name="requireReauthenticationToApprove")
    def require_reauthentication_to_approve(self) -> pulumi.Output[_builtins.bool]:
        """
        Require approver to authenticate before adding the approval.
        """
        return pulumi.get(self, "require_reauthentication_to_approve")

    @_builtins.property
    @pulumi.getter(name="retainApprovalsOnPush")
    def retain_approvals_on_push(self) -> pulumi.Output[_builtins.bool]:
        """
        Retain approval count on a new push.
        """
        return pulumi.get(self, "retain_approvals_on_push")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetGroupSamlLinksResult',
    'AwaitableGetGroupSamlLinksResult',
    'get_group_saml_links',
    'get_group_saml_links_output',
]

@pulumi.output_type
class GetGroupSamlLinksResult:
    """
    A collection of values returned by getGroupSamlLinks.
    """
    def __init__(__self__, group=None, id=None, saml_links=None):
        if group and not isinstance(group, str):
            raise TypeError("Expected argument 'group' to be a str")
        pulumi.set(__self__, "group", group)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if saml_links and not isinstance(saml_links, list):
            raise TypeError("Expected argument 'saml_links' to be a list")
        pulumi.set(__self__, "saml_links", saml_links)

    @_builtins.property
    @pulumi.getter
    def group(self) -> _builtins.str:
        """
        The name or id of the group.
        """
        return pulumi.get(self, "group")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="samlLinks")
    def saml_links(self) -> Sequence['outputs.GetGroupSamlLinksSamlLinkResult']:
        """
        The list of group SAML links returned by the search
        """
        return pulumi.get(self, "saml_links")


class AwaitableGetGroupSamlLinksResult(GetGroupSamlLinksResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupSamlLinksResult(
            group=self.group,
            id=self.id,
            saml_links=self.saml_links)


def get_group_saml_links(group: Optional[_builtins.str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGroupSamlLinksResult:
    """
    The `get_group_saml_links` data source retrieves all SAML links for a specified group.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/saml/#saml-group-links)

    ## Example Usage


    :param _builtins.str group: The name or id of the group.
    """
    __args__ = dict()
    __args__['group'] = group
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getGroupSamlLinks:getGroupSamlLinks', __args__, opts=opts, typ=GetGroupSamlLinksResult).value

    return AwaitableGetGroupSamlLinksResult(
        group=pulumi.get(__ret__, 'group'),
        id=pulumi.get(__ret__, 'id'),
        saml_links=pulumi.get(__ret__, 'saml_links'))
def get_group_saml_links_output(group: Optional[pulumi.Input[_builtins.str]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGroupSamlLinksResult]:
    """
    The `get_group_saml_links` data source retrieves all SAML links for a specified group.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/saml/#saml-group-links)

    ## Example Usage


    :param _builtins.str group: The name or id of the group.
    """
    __args__ = dict()
    __args__['group'] = group
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getGroupSamlLinks:getGroupSamlLinks', __args__, opts=opts, typ=GetGroupSamlLinksResult)
    return __ret__.apply(lambda __response__: GetGroupSamlLinksResult(
        group=pulumi.get(__response__, 'group'),
        id=pulumi.get(__response__, 'id'),
        saml_links=pulumi.get(__response__, 'saml_links')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['GroupDependencyProxyArgs', 'GroupDependencyProxy']

@pulumi.input_type
class GroupDependencyProxyArgs:
    def __init__(__self__, *,
                 group: pulumi.Input[_builtins.str],
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 identity: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a GroupDependencyProxy resource.
        :param pulumi.Input[_builtins.str] group: The ID or URL-encoded path of the group.
        :param pulumi.Input[_builtins.bool] enabled: Indicates whether the proxy is enabled.
        :param pulumi.Input[_builtins.str] identity: Identity credential used to authenticate with Docker Hub when pulling images. Can be a username (for password or personal access token (PAT)) or organization name (for organization access token (OAT)).
        :param pulumi.Input[_builtins.str] secret: Secret credential used to authenticate with Docker Hub when pulling images. Can be a password, personal access token (PAT), or organization access token (OAT). Cannot be imported.
        """
        pulumi.set(__self__, "group", group)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if identity is not None:
            pulumi.set(__self__, "identity", identity)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)

    @_builtins.property
    @pulumi.getter
    def group(self) -> pulumi.Input[_builtins.str]:
        """
        The ID or URL-encoded path of the group.
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "group", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the proxy is enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def identity(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identity credential used to authenticate with Docker Hub when pulling images. Can be a username (for password or personal access token (PAT)) or organization name (for organization access token (OAT)).
        """
        return pulumi.get(self, "identity")

    @identity.setter
    def identity(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identity", value)

    @_builtins.property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Secret credential used to authenticate with Docker Hub when pulling images. Can be a password, personal access token (PAT), or organization access token (OAT). Cannot be imported.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret", value)


@pulumi.input_type
class _GroupDependencyProxyState:
    def __init__(__self__, *,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 group: Optional[pulumi.Input[_builtins.str]] = None,
                 identity: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering GroupDependencyProxy resources.
        :param pulumi.Input[_builtins.bool] enabled: Indicates whether the proxy is enabled.
        :param pulumi.Input[_builtins.str] group: The ID or URL-encoded path of the group.
        :param pulumi.Input[_builtins.str] identity: Identity credential used to authenticate with Docker Hub when pulling images. Can be a username (for password or personal access token (PAT)) or organization name (for organization access token (OAT)).
        :param pulumi.Input[_builtins.str] secret: Secret credential used to authenticate with Docker Hub when pulling images. Can be a password, personal access token (PAT), or organization access token (OAT). Cannot be imported.
        """
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if group is not None:
            pulumi.set(__self__, "group", group)
        if identity is not None:
            pulumi.set(__self__, "identity", identity)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the proxy is enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def group(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID or URL-encoded path of the group.
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "group", value)

    @_builtins.property
    @pulumi.getter
    def identity(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identity credential used to authenticate with Docker Hub when pulling images. Can be a username (for password or personal access token (PAT)) or organization name (for organization access token (OAT)).
        """
        return pulumi.get(self, "identity")

    @identity.setter
    def identity(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identity", value)

    @_builtins.property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Secret credential used to authenticate with Docker Hub when pulling images. Can be a password, personal access token (PAT), or organization access token (OAT). Cannot be imported.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret", value)


@pulumi.type_token("gitlab:index/groupDependencyProxy:GroupDependencyProxy")
class GroupDependencyProxy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 group: Optional[pulumi.Input[_builtins.str]] = None,
                 identity: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `GroupDependencyProxy` resource allows managing the group docker dependency proxy. More than one dependency proxy per group will conflict with each other.

        If you're looking to manage the project-level package dependency proxy, see the `gitlab_project_package_registry_proxy` resource instead.

        **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/api/graphql/reference/#mutationupdatedependencyproxysettings)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        foo = gitlab.GroupDependencyProxy("foo",
            group="1234",
            enabled=True,
            identity="newidentity",
            secret="somesecret")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_group_dependency_proxy`. For example:

        terraform

        import {

          to = gitlab_group_dependency_proxy.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        You can import a group dependency proxy using the group id. e.g. `{group-id}`

        "secret" will not populate when importing the dependency proxy, but will still

        be required in the configuration.

        ```sh
        $ pulumi import gitlab:index/groupDependencyProxy:GroupDependencyProxy foo 42
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] enabled: Indicates whether the proxy is enabled.
        :param pulumi.Input[_builtins.str] group: The ID or URL-encoded path of the group.
        :param pulumi.Input[_builtins.str] identity: Identity credential used to authenticate with Docker Hub when pulling images. Can be a username (for password or personal access token (PAT)) or organization name (for organization access token (OAT)).
        :param pulumi.Input[_builtins.str] secret: Secret credential used to authenticate with Docker Hub when pulling images. Can be a password, personal access token (PAT), or organization access token (OAT). Cannot be imported.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupDependencyProxyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `GroupDependencyProxy` resource allows managing the group docker dependency proxy. More than one dependency proxy per group will conflict with each other.

        If you're looking to manage the project-level package dependency proxy, see the `gitlab_project_package_registry_proxy` resource instead.

        **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/api/graphql/reference/#mutationupdatedependencyproxysettings)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        foo = gitlab.GroupDependencyProxy("foo",
            group="1234",
            enabled=True,
            identity="newidentity",
            secret="somesecret")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_group_dependency_proxy`. For example:

        terraform

        import {

          to = gitlab_group_dependency_proxy.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        You can import a group dependency proxy using the group id. e.g. `{group-id}`

        "secret" will not populate when importing the dependency proxy, but will still

        be required in the configuration.

        ```sh
        $ pulumi import gitlab:index/groupDependencyProxy:GroupDependencyProxy foo 42
        ```

        :param str resource_name: The name of the resource.
        :param GroupDependencyProxyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupDependencyProxyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 group: Optional[pulumi.Input[_builtins.str]] = None,
                 identity: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupDependencyProxyArgs.__new__(GroupDependencyProxyArgs)

            __props__.__dict__["enabled"] = enabled
            if group is None and not opts.urn:
                raise TypeError("Missing required property 'group'")
            __props__.__dict__["group"] = group
            __props__.__dict__["identity"] = identity
            __props__.__dict__["secret"] = None if secret is None else pulumi.Output.secret(secret)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["secret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(GroupDependencyProxy, __self__).__init__(
            'gitlab:index/groupDependencyProxy:GroupDependencyProxy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            group: Optional[pulumi.Input[_builtins.str]] = None,
            identity: Optional[pulumi.Input[_builtins.str]] = None,
            secret: Optional[pulumi.Input[_builtins.str]] = None) -> 'GroupDependencyProxy':
        """
        Get an existing GroupDependencyProxy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] enabled: Indicates whether the proxy is enabled.
        :param pulumi.Input[_builtins.str] group: The ID or URL-encoded path of the group.
        :param pulumi.Input[_builtins.str] identity: Identity credential used to authenticate with Docker Hub when pulling images. Can be a username (for password or personal access token (PAT)) or organization name (for organization access token (OAT)).
        :param pulumi.Input[_builtins.str] secret: Secret credential used to authenticate with Docker Hub when pulling images. Can be a password, personal access token (PAT), or organization access token (OAT). Cannot be imported.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupDependencyProxyState.__new__(_GroupDependencyProxyState)

        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["group"] = group
        __props__.__dict__["identity"] = identity
        __props__.__dict__["secret"] = secret
        return GroupDependencyProxy(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether the proxy is enabled.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def group(self) -> pulumi.Output[_builtins.str]:
        """
        The ID or URL-encoded path of the group.
        """
        return pulumi.get(self, "group")

    @_builtins.property
    @pulumi.getter
    def identity(self) -> pulumi.Output[_builtins.str]:
        """
        Identity credential used to authenticate with Docker Hub when pulling images. Can be a username (for password or personal access token (PAT)) or organization name (for organization access token (OAT)).
        """
        return pulumi.get(self, "identity")

    @_builtins.property
    @pulumi.getter
    def secret(self) -> pulumi.Output[_builtins.str]:
        """
        Secret credential used to authenticate with Docker Hub when pulling images. Can be a password, personal access token (PAT), or organization access token (OAT). Cannot be imported.
        """
        return pulumi.get(self, "secret")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['IntegrationHarborArgs', 'IntegrationHarbor']

@pulumi.input_type
class IntegrationHarborArgs:
    def __init__(__self__, *,
                 password: pulumi.Input[_builtins.str],
                 project: pulumi.Input[_builtins.str],
                 project_name: pulumi.Input[_builtins.str],
                 url: pulumi.Input[_builtins.str],
                 username: pulumi.Input[_builtins.str],
                 use_inherited_settings: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a IntegrationHarbor resource.
        :param pulumi.Input[_builtins.str] password: Password for authentication with the Harbor server, if authentication is required by the server.
        :param pulumi.Input[_builtins.str] project: ID of the GitLab project you want to activate integration on.
        :param pulumi.Input[_builtins.str] project_name: The URL-friendly Harbor project name. This project needs to already exist in Harbor. Example: `my_project_name`.
        :param pulumi.Input[_builtins.str] url: Harbor URL. Example: `http://harbor.example.com`
        :param pulumi.Input[_builtins.str] username: Username for authentication with the Harbor server, if authentication is required by the server.
        :param pulumi.Input[_builtins.bool] use_inherited_settings: Indicates whether or not to inherit default settings. Defaults to false.
        """
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "project_name", project_name)
        pulumi.set(__self__, "url", url)
        pulumi.set(__self__, "username", username)
        if use_inherited_settings is not None:
            pulumi.set(__self__, "use_inherited_settings", use_inherited_settings)

    @_builtins.property
    @pulumi.getter
    def password(self) -> pulumi.Input[_builtins.str]:
        """
        Password for authentication with the Harbor server, if authentication is required by the server.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the GitLab project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Input[_builtins.str]:
        """
        The URL-friendly Harbor project name. This project needs to already exist in Harbor. Example: `my_project_name`.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_name", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Input[_builtins.str]:
        """
        Harbor URL. Example: `http://harbor.example.com`
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "url", value)

    @_builtins.property
    @pulumi.getter
    def username(self) -> pulumi.Input[_builtins.str]:
        """
        Username for authentication with the Harbor server, if authentication is required by the server.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "username", value)

    @_builtins.property
    @pulumi.getter(name="useInheritedSettings")
    def use_inherited_settings(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether or not to inherit default settings. Defaults to false.
        """
        return pulumi.get(self, "use_inherited_settings")

    @use_inherited_settings.setter
    def use_inherited_settings(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "use_inherited_settings", value)


@pulumi.input_type
class _IntegrationHarborState:
    def __init__(__self__, *,
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 project_name: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 use_inherited_settings: Optional[pulumi.Input[_builtins.bool]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering IntegrationHarbor resources.
        :param pulumi.Input[_builtins.bool] active: Whether the integration is active.
        :param pulumi.Input[_builtins.str] password: Password for authentication with the Harbor server, if authentication is required by the server.
        :param pulumi.Input[_builtins.str] project: ID of the GitLab project you want to activate integration on.
        :param pulumi.Input[_builtins.str] project_name: The URL-friendly Harbor project name. This project needs to already exist in Harbor. Example: `my_project_name`.
        :param pulumi.Input[_builtins.str] url: Harbor URL. Example: `http://harbor.example.com`
        :param pulumi.Input[_builtins.bool] use_inherited_settings: Indicates whether or not to inherit default settings. Defaults to false.
        :param pulumi.Input[_builtins.str] username: Username for authentication with the Harbor server, if authentication is required by the server.
        """
        if active is not None:
            pulumi.set(__self__, "active", active)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if use_inherited_settings is not None:
            pulumi.set(__self__, "use_inherited_settings", use_inherited_settings)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the integration is active.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "active", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Password for authentication with the Harbor server, if authentication is required by the server.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the GitLab project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL-friendly Harbor project name. This project needs to already exist in Harbor. Example: `my_project_name`.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_name", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Harbor URL. Example: `http://harbor.example.com`
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "url", value)

    @_builtins.property
    @pulumi.getter(name="useInheritedSettings")
    def use_inherited_settings(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether or not to inherit default settings. Defaults to false.
        """
        return pulumi.get(self, "use_inherited_settings")

    @use_inherited_settings.setter
    def use_inherited_settings(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "use_inherited_settings", value)

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username for authentication with the Harbor server, if authentication is required by the server.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "username", value)


@pulumi.type_token("gitlab:index/integrationHarbor:IntegrationHarbor")
class IntegrationHarbor(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 project_name: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 use_inherited_settings: Optional[pulumi.Input[_builtins.bool]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `IntegrationHarbor` resource manages the lifecycle of a project integration with Harbor.

        > This resource is deprecated and will be removed in 19.0. Use `ProjectIntegrationHarbor`instead.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/project_integrations/#harbor)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        awesome_project = gitlab.Project("awesome_project",
            name="awesome_project",
            description="My awesome project.",
            visibility_level="public")
        config = pulumi.Config()
        # Harbor password
        password = config.require("password")
        harbor = gitlab.IntegrationHarbor("harbor",
            project=awesome_project.id,
            url="http://harbor.example.com",
            project_name="my_project_name",
            username="username",
            password=password)
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_integration_harbor`. For example:

        terraform

        import {

          to = gitlab_integration_harbor.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        ```sh
        $ pulumi import gitlab:index/integrationHarbor:IntegrationHarbor You can import a gitlab_integration_harbor state using `<resource> <project_id>`:
        ```

        ```sh
        $ pulumi import gitlab:index/integrationHarbor:IntegrationHarbor harbor 1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] password: Password for authentication with the Harbor server, if authentication is required by the server.
        :param pulumi.Input[_builtins.str] project: ID of the GitLab project you want to activate integration on.
        :param pulumi.Input[_builtins.str] project_name: The URL-friendly Harbor project name. This project needs to already exist in Harbor. Example: `my_project_name`.
        :param pulumi.Input[_builtins.str] url: Harbor URL. Example: `http://harbor.example.com`
        :param pulumi.Input[_builtins.bool] use_inherited_settings: Indicates whether or not to inherit default settings. Defaults to false.
        :param pulumi.Input[_builtins.str] username: Username for authentication with the Harbor server, if authentication is required by the server.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IntegrationHarborArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `IntegrationHarbor` resource manages the lifecycle of a project integration with Harbor.

        > This resource is deprecated and will be removed in 19.0. Use `ProjectIntegrationHarbor`instead.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/project_integrations/#harbor)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        awesome_project = gitlab.Project("awesome_project",
            name="awesome_project",
            description="My awesome project.",
            visibility_level="public")
        config = pulumi.Config()
        # Harbor password
        password = config.require("password")
        harbor = gitlab.IntegrationHarbor("harbor",
            project=awesome_project.id,
            url="http://harbor.example.com",
            project_name="my_project_name",
            username="username",
            password=password)
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_integration_harbor`. For example:

        terraform

        import {

          to = gitlab_integration_harbor.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        ```sh
        $ pulumi import gitlab:index/integrationHarbor:IntegrationHarbor You can import a gitlab_integration_harbor state using `<resource> <project_id>`:
        ```

        ```sh
        $ pulumi import gitlab:index/integrationHarbor:IntegrationHarbor harbor 1
        ```

        :param str resource_name: The name of the resource.
        :param IntegrationHarborArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IntegrationHarborArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 project_name: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 use_inherited_settings: Optional[pulumi.Input[_builtins.bool]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IntegrationHarborArgs.__new__(IntegrationHarborArgs)

            if password is None and not opts.urn:
                raise TypeError("Missing required property 'password'")
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if project_name is None and not opts.urn:
                raise TypeError("Missing required property 'project_name'")
            __props__.__dict__["project_name"] = project_name
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = url
            __props__.__dict__["use_inherited_settings"] = use_inherited_settings
            if username is None and not opts.urn:
                raise TypeError("Missing required property 'username'")
            __props__.__dict__["username"] = username
            __props__.__dict__["active"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(IntegrationHarbor, __self__).__init__(
            'gitlab:index/integrationHarbor:IntegrationHarbor',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            active: Optional[pulumi.Input[_builtins.bool]] = None,
            password: Optional[pulumi.Input[_builtins.str]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None,
            project_name: Optional[pulumi.Input[_builtins.str]] = None,
            url: Optional[pulumi.Input[_builtins.str]] = None,
            use_inherited_settings: Optional[pulumi.Input[_builtins.bool]] = None,
            username: Optional[pulumi.Input[_builtins.str]] = None) -> 'IntegrationHarbor':
        """
        Get an existing IntegrationHarbor resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] active: Whether the integration is active.
        :param pulumi.Input[_builtins.str] password: Password for authentication with the Harbor server, if authentication is required by the server.
        :param pulumi.Input[_builtins.str] project: ID of the GitLab project you want to activate integration on.
        :param pulumi.Input[_builtins.str] project_name: The URL-friendly Harbor project name. This project needs to already exist in Harbor. Example: `my_project_name`.
        :param pulumi.Input[_builtins.str] url: Harbor URL. Example: `http://harbor.example.com`
        :param pulumi.Input[_builtins.bool] use_inherited_settings: Indicates whether or not to inherit default settings. Defaults to false.
        :param pulumi.Input[_builtins.str] username: Username for authentication with the Harbor server, if authentication is required by the server.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IntegrationHarborState.__new__(_IntegrationHarborState)

        __props__.__dict__["active"] = active
        __props__.__dict__["password"] = password
        __props__.__dict__["project"] = project
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["url"] = url
        __props__.__dict__["use_inherited_settings"] = use_inherited_settings
        __props__.__dict__["username"] = username
        return IntegrationHarbor(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def active(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the integration is active.
        """
        return pulumi.get(self, "active")

    @_builtins.property
    @pulumi.getter
    def password(self) -> pulumi.Output[_builtins.str]:
        """
        Password for authentication with the Harbor server, if authentication is required by the server.
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the GitLab project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[_builtins.str]:
        """
        The URL-friendly Harbor project name. This project needs to already exist in Harbor. Example: `my_project_name`.
        """
        return pulumi.get(self, "project_name")

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Output[_builtins.str]:
        """
        Harbor URL. Example: `http://harbor.example.com`
        """
        return pulumi.get(self, "url")

    @_builtins.property
    @pulumi.getter(name="useInheritedSettings")
    def use_inherited_settings(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether or not to inherit default settings. Defaults to false.
        """
        return pulumi.get(self, "use_inherited_settings")

    @_builtins.property
    @pulumi.getter
    def username(self) -> pulumi.Output[_builtins.str]:
        """
        Username for authentication with the Harbor server, if authentication is required by the server.
        """
        return pulumi.get(self, "username")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetGroupHookResult',
    'AwaitableGetGroupHookResult',
    'get_group_hook',
    'get_group_hook_output',
]

@pulumi.output_type
class GetGroupHookResult:
    """
    A collection of values returned by getGroupHook.
    """
    def __init__(__self__, confidential_issues_events=None, confidential_note_events=None, custom_webhook_template=None, deployment_events=None, emoji_events=None, enable_ssl_verification=None, group=None, group_id=None, hook_id=None, id=None, issues_events=None, job_events=None, merge_requests_events=None, note_events=None, pipeline_events=None, push_events=None, push_events_branch_filter=None, releases_events=None, subgroup_events=None, tag_push_events=None, token=None, url=None, wiki_page_events=None):
        if confidential_issues_events and not isinstance(confidential_issues_events, bool):
            raise TypeError("Expected argument 'confidential_issues_events' to be a bool")
        pulumi.set(__self__, "confidential_issues_events", confidential_issues_events)
        if confidential_note_events and not isinstance(confidential_note_events, bool):
            raise TypeError("Expected argument 'confidential_note_events' to be a bool")
        pulumi.set(__self__, "confidential_note_events", confidential_note_events)
        if custom_webhook_template and not isinstance(custom_webhook_template, str):
            raise TypeError("Expected argument 'custom_webhook_template' to be a str")
        pulumi.set(__self__, "custom_webhook_template", custom_webhook_template)
        if deployment_events and not isinstance(deployment_events, bool):
            raise TypeError("Expected argument 'deployment_events' to be a bool")
        pulumi.set(__self__, "deployment_events", deployment_events)
        if emoji_events and not isinstance(emoji_events, bool):
            raise TypeError("Expected argument 'emoji_events' to be a bool")
        pulumi.set(__self__, "emoji_events", emoji_events)
        if enable_ssl_verification and not isinstance(enable_ssl_verification, bool):
            raise TypeError("Expected argument 'enable_ssl_verification' to be a bool")
        pulumi.set(__self__, "enable_ssl_verification", enable_ssl_verification)
        if group and not isinstance(group, str):
            raise TypeError("Expected argument 'group' to be a str")
        pulumi.set(__self__, "group", group)
        if group_id and not isinstance(group_id, int):
            raise TypeError("Expected argument 'group_id' to be a int")
        pulumi.set(__self__, "group_id", group_id)
        if hook_id and not isinstance(hook_id, int):
            raise TypeError("Expected argument 'hook_id' to be a int")
        pulumi.set(__self__, "hook_id", hook_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if issues_events and not isinstance(issues_events, bool):
            raise TypeError("Expected argument 'issues_events' to be a bool")
        pulumi.set(__self__, "issues_events", issues_events)
        if job_events and not isinstance(job_events, bool):
            raise TypeError("Expected argument 'job_events' to be a bool")
        pulumi.set(__self__, "job_events", job_events)
        if merge_requests_events and not isinstance(merge_requests_events, bool):
            raise TypeError("Expected argument 'merge_requests_events' to be a bool")
        pulumi.set(__self__, "merge_requests_events", merge_requests_events)
        if note_events and not isinstance(note_events, bool):
            raise TypeError("Expected argument 'note_events' to be a bool")
        pulumi.set(__self__, "note_events", note_events)
        if pipeline_events and not isinstance(pipeline_events, bool):
            raise TypeError("Expected argument 'pipeline_events' to be a bool")
        pulumi.set(__self__, "pipeline_events", pipeline_events)
        if push_events and not isinstance(push_events, bool):
            raise TypeError("Expected argument 'push_events' to be a bool")
        pulumi.set(__self__, "push_events", push_events)
        if push_events_branch_filter and not isinstance(push_events_branch_filter, str):
            raise TypeError("Expected argument 'push_events_branch_filter' to be a str")
        pulumi.set(__self__, "push_events_branch_filter", push_events_branch_filter)
        if releases_events and not isinstance(releases_events, bool):
            raise TypeError("Expected argument 'releases_events' to be a bool")
        pulumi.set(__self__, "releases_events", releases_events)
        if subgroup_events and not isinstance(subgroup_events, bool):
            raise TypeError("Expected argument 'subgroup_events' to be a bool")
        pulumi.set(__self__, "subgroup_events", subgroup_events)
        if tag_push_events and not isinstance(tag_push_events, bool):
            raise TypeError("Expected argument 'tag_push_events' to be a bool")
        pulumi.set(__self__, "tag_push_events", tag_push_events)
        if token and not isinstance(token, str):
            raise TypeError("Expected argument 'token' to be a str")
        pulumi.set(__self__, "token", token)
        if url and not isinstance(url, str):
            raise TypeError("Expected argument 'url' to be a str")
        pulumi.set(__self__, "url", url)
        if wiki_page_events and not isinstance(wiki_page_events, bool):
            raise TypeError("Expected argument 'wiki_page_events' to be a bool")
        pulumi.set(__self__, "wiki_page_events", wiki_page_events)

    @_builtins.property
    @pulumi.getter(name="confidentialIssuesEvents")
    def confidential_issues_events(self) -> _builtins.bool:
        """
        Invoke the hook for confidential issues events.
        """
        return pulumi.get(self, "confidential_issues_events")

    @_builtins.property
    @pulumi.getter(name="confidentialNoteEvents")
    def confidential_note_events(self) -> _builtins.bool:
        """
        Invoke the hook for confidential notes events.
        """
        return pulumi.get(self, "confidential_note_events")

    @_builtins.property
    @pulumi.getter(name="customWebhookTemplate")
    def custom_webhook_template(self) -> _builtins.str:
        """
        Set a custom webhook template.
        """
        return pulumi.get(self, "custom_webhook_template")

    @_builtins.property
    @pulumi.getter(name="deploymentEvents")
    def deployment_events(self) -> _builtins.bool:
        """
        Invoke the hook for deployment events.
        """
        return pulumi.get(self, "deployment_events")

    @_builtins.property
    @pulumi.getter(name="emojiEvents")
    def emoji_events(self) -> _builtins.bool:
        """
        Invoke the hook for emoji events.
        """
        return pulumi.get(self, "emoji_events")

    @_builtins.property
    @pulumi.getter(name="enableSslVerification")
    def enable_ssl_verification(self) -> _builtins.bool:
        """
        Enable ssl verification when invoking the hook.
        """
        return pulumi.get(self, "enable_ssl_verification")

    @_builtins.property
    @pulumi.getter
    def group(self) -> _builtins.str:
        """
        The ID or full path of the group.
        """
        return pulumi.get(self, "group")

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> _builtins.int:
        """
        The id of the group for the hook.
        """
        return pulumi.get(self, "group_id")

    @_builtins.property
    @pulumi.getter(name="hookId")
    def hook_id(self) -> _builtins.int:
        """
        The id of the group hook.
        """
        return pulumi.get(self, "hook_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of this data source. In the format `<group:hook_id>`.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="issuesEvents")
    def issues_events(self) -> _builtins.bool:
        """
        Invoke the hook for issues events.
        """
        return pulumi.get(self, "issues_events")

    @_builtins.property
    @pulumi.getter(name="jobEvents")
    def job_events(self) -> _builtins.bool:
        """
        Invoke the hook for job events.
        """
        return pulumi.get(self, "job_events")

    @_builtins.property
    @pulumi.getter(name="mergeRequestsEvents")
    def merge_requests_events(self) -> _builtins.bool:
        """
        Invoke the hook for merge requests.
        """
        return pulumi.get(self, "merge_requests_events")

    @_builtins.property
    @pulumi.getter(name="noteEvents")
    def note_events(self) -> _builtins.bool:
        """
        Invoke the hook for notes events.
        """
        return pulumi.get(self, "note_events")

    @_builtins.property
    @pulumi.getter(name="pipelineEvents")
    def pipeline_events(self) -> _builtins.bool:
        """
        Invoke the hook for pipeline events.
        """
        return pulumi.get(self, "pipeline_events")

    @_builtins.property
    @pulumi.getter(name="pushEvents")
    def push_events(self) -> _builtins.bool:
        """
        Invoke the hook for push events.
        """
        return pulumi.get(self, "push_events")

    @_builtins.property
    @pulumi.getter(name="pushEventsBranchFilter")
    def push_events_branch_filter(self) -> _builtins.str:
        """
        Invoke the hook for push events on matching branches only.
        """
        return pulumi.get(self, "push_events_branch_filter")

    @_builtins.property
    @pulumi.getter(name="releasesEvents")
    def releases_events(self) -> _builtins.bool:
        """
        Invoke the hook for releases events.
        """
        return pulumi.get(self, "releases_events")

    @_builtins.property
    @pulumi.getter(name="subgroupEvents")
    def subgroup_events(self) -> _builtins.bool:
        """
        Invoke the hook for subgroup events.
        """
        return pulumi.get(self, "subgroup_events")

    @_builtins.property
    @pulumi.getter(name="tagPushEvents")
    def tag_push_events(self) -> _builtins.bool:
        """
        Invoke the hook for tag push events.
        """
        return pulumi.get(self, "tag_push_events")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""The token is only available on resource creation, not in this datasource. It will always be blank. To be removed in 19.0.""")
    def token(self) -> _builtins.str:
        """
        A token to present when invoking the hook. The token is only available on resource creation, not in this datasource. It will always be blank. To be removed in 19.0.
        """
        return pulumi.get(self, "token")

    @_builtins.property
    @pulumi.getter
    def url(self) -> _builtins.str:
        """
        The url of the hook to invoke.
        """
        return pulumi.get(self, "url")

    @_builtins.property
    @pulumi.getter(name="wikiPageEvents")
    def wiki_page_events(self) -> _builtins.bool:
        """
        Invoke the hook for wiki page events.
        """
        return pulumi.get(self, "wiki_page_events")


class AwaitableGetGroupHookResult(GetGroupHookResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupHookResult(
            confidential_issues_events=self.confidential_issues_events,
            confidential_note_events=self.confidential_note_events,
            custom_webhook_template=self.custom_webhook_template,
            deployment_events=self.deployment_events,
            emoji_events=self.emoji_events,
            enable_ssl_verification=self.enable_ssl_verification,
            group=self.group,
            group_id=self.group_id,
            hook_id=self.hook_id,
            id=self.id,
            issues_events=self.issues_events,
            job_events=self.job_events,
            merge_requests_events=self.merge_requests_events,
            note_events=self.note_events,
            pipeline_events=self.pipeline_events,
            push_events=self.push_events,
            push_events_branch_filter=self.push_events_branch_filter,
            releases_events=self.releases_events,
            subgroup_events=self.subgroup_events,
            tag_push_events=self.tag_push_events,
            token=self.token,
            url=self.url,
            wiki_page_events=self.wiki_page_events)


def get_group_hook(group: Optional[_builtins.str] = None,
                   hook_id: Optional[_builtins.int] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGroupHookResult:
    """
    The `GroupHook` data source allows to retrieve details about a hook in a group.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/group_webhooks/#get-a-group-hook)

    ## Example Usage


    :param _builtins.str group: The ID or full path of the group.
    :param _builtins.int hook_id: The id of the group hook.
    """
    __args__ = dict()
    __args__['group'] = group
    __args__['hookId'] = hook_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getGroupHook:getGroupHook', __args__, opts=opts, typ=GetGroupHookResult).value

    return AwaitableGetGroupHookResult(
        confidential_issues_events=pulumi.get(__ret__, 'confidential_issues_events'),
        confidential_note_events=pulumi.get(__ret__, 'confidential_note_events'),
        custom_webhook_template=pulumi.get(__ret__, 'custom_webhook_template'),
        deployment_events=pulumi.get(__ret__, 'deployment_events'),
        emoji_events=pulumi.get(__ret__, 'emoji_events'),
        enable_ssl_verification=pulumi.get(__ret__, 'enable_ssl_verification'),
        group=pulumi.get(__ret__, 'group'),
        group_id=pulumi.get(__ret__, 'group_id'),
        hook_id=pulumi.get(__ret__, 'hook_id'),
        id=pulumi.get(__ret__, 'id'),
        issues_events=pulumi.get(__ret__, 'issues_events'),
        job_events=pulumi.get(__ret__, 'job_events'),
        merge_requests_events=pulumi.get(__ret__, 'merge_requests_events'),
        note_events=pulumi.get(__ret__, 'note_events'),
        pipeline_events=pulumi.get(__ret__, 'pipeline_events'),
        push_events=pulumi.get(__ret__, 'push_events'),
        push_events_branch_filter=pulumi.get(__ret__, 'push_events_branch_filter'),
        releases_events=pulumi.get(__ret__, 'releases_events'),
        subgroup_events=pulumi.get(__ret__, 'subgroup_events'),
        tag_push_events=pulumi.get(__ret__, 'tag_push_events'),
        token=pulumi.get(__ret__, 'token'),
        url=pulumi.get(__ret__, 'url'),
        wiki_page_events=pulumi.get(__ret__, 'wiki_page_events'))
def get_group_hook_output(group: Optional[pulumi.Input[_builtins.str]] = None,
                          hook_id: Optional[pulumi.Input[_builtins.int]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGroupHookResult]:
    """
    The `GroupHook` data source allows to retrieve details about a hook in a group.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/group_webhooks/#get-a-group-hook)

    ## Example Usage


    :param _builtins.str group: The ID or full path of the group.
    :param _builtins.int hook_id: The id of the group hook.
    """
    __args__ = dict()
    __args__['group'] = group
    __args__['hookId'] = hook_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getGroupHook:getGroupHook', __args__, opts=opts, typ=GetGroupHookResult)
    return __ret__.apply(lambda __response__: GetGroupHookResult(
        confidential_issues_events=pulumi.get(__response__, 'confidential_issues_events'),
        confidential_note_events=pulumi.get(__response__, 'confidential_note_events'),
        custom_webhook_template=pulumi.get(__response__, 'custom_webhook_template'),
        deployment_events=pulumi.get(__response__, 'deployment_events'),
        emoji_events=pulumi.get(__response__, 'emoji_events'),
        enable_ssl_verification=pulumi.get(__response__, 'enable_ssl_verification'),
        group=pulumi.get(__response__, 'group'),
        group_id=pulumi.get(__response__, 'group_id'),
        hook_id=pulumi.get(__response__, 'hook_id'),
        id=pulumi.get(__response__, 'id'),
        issues_events=pulumi.get(__response__, 'issues_events'),
        job_events=pulumi.get(__response__, 'job_events'),
        merge_requests_events=pulumi.get(__response__, 'merge_requests_events'),
        note_events=pulumi.get(__response__, 'note_events'),
        pipeline_events=pulumi.get(__response__, 'pipeline_events'),
        push_events=pulumi.get(__response__, 'push_events'),
        push_events_branch_filter=pulumi.get(__response__, 'push_events_branch_filter'),
        releases_events=pulumi.get(__response__, 'releases_events'),
        subgroup_events=pulumi.get(__response__, 'subgroup_events'),
        tag_push_events=pulumi.get(__response__, 'tag_push_events'),
        token=pulumi.get(__response__, 'token'),
        url=pulumi.get(__response__, 'url'),
        wiki_page_events=pulumi.get(__response__, 'wiki_page_events')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetProjectApprovalRulesResult',
    'AwaitableGetProjectApprovalRulesResult',
    'get_project_approval_rules',
    'get_project_approval_rules_output',
]

@pulumi.output_type
class GetProjectApprovalRulesResult:
    """
    A collection of values returned by getProjectApprovalRules.
    """
    def __init__(__self__, approval_rules=None, id=None, project=None):
        if approval_rules and not isinstance(approval_rules, list):
            raise TypeError("Expected argument 'approval_rules' to be a list")
        pulumi.set(__self__, "approval_rules", approval_rules)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)

    @_builtins.property
    @pulumi.getter(name="approvalRules")
    def approval_rules(self) -> Optional[Sequence['outputs.GetProjectApprovalRulesApprovalRuleResult']]:
        """
        A list of project approval rules, as defined below.
        """
        return pulumi.get(self, "approval_rules")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def project(self) -> _builtins.str:
        """
        The ID or path with namespace that identifies the project.
        """
        return pulumi.get(self, "project")


class AwaitableGetProjectApprovalRulesResult(GetProjectApprovalRulesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectApprovalRulesResult(
            approval_rules=self.approval_rules,
            id=self.id,
            project=self.project)


def get_project_approval_rules(approval_rules: Optional[Sequence[Union['GetProjectApprovalRulesApprovalRuleArgs', 'GetProjectApprovalRulesApprovalRuleArgsDict']]] = None,
                               project: Optional[_builtins.str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectApprovalRulesResult:
    """
    The `get_project_approval_rules` data source retrieves all approval rules of a given project.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/merge_request_approvals/#list-all-approval-rules-for-a-project)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    by_project_id = gitlab.get_project_approval_rules(project="12345")
    by_project_path = gitlab.get_project_approval_rules(project="my-group/my-project")
    ```


    :param Sequence[Union['GetProjectApprovalRulesApprovalRuleArgs', 'GetProjectApprovalRulesApprovalRuleArgsDict']] approval_rules: A list of project approval rules, as defined below.
    :param _builtins.str project: The ID or path with namespace that identifies the project.
    """
    __args__ = dict()
    __args__['approvalRules'] = approval_rules
    __args__['project'] = project
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getProjectApprovalRules:getProjectApprovalRules', __args__, opts=opts, typ=GetProjectApprovalRulesResult).value

    return AwaitableGetProjectApprovalRulesResult(
        approval_rules=pulumi.get(__ret__, 'approval_rules'),
        id=pulumi.get(__ret__, 'id'),
        project=pulumi.get(__ret__, 'project'))
def get_project_approval_rules_output(approval_rules: Optional[pulumi.Input[Optional[Sequence[Union['GetProjectApprovalRulesApprovalRuleArgs', 'GetProjectApprovalRulesApprovalRuleArgsDict']]]]] = None,
                                      project: Optional[pulumi.Input[_builtins.str]] = None,
                                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectApprovalRulesResult]:
    """
    The `get_project_approval_rules` data source retrieves all approval rules of a given project.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/merge_request_approvals/#list-all-approval-rules-for-a-project)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    by_project_id = gitlab.get_project_approval_rules(project="12345")
    by_project_path = gitlab.get_project_approval_rules(project="my-group/my-project")
    ```


    :param Sequence[Union['GetProjectApprovalRulesApprovalRuleArgs', 'GetProjectApprovalRulesApprovalRuleArgsDict']] approval_rules: A list of project approval rules, as defined below.
    :param _builtins.str project: The ID or path with namespace that identifies the project.
    """
    __args__ = dict()
    __args__['approvalRules'] = approval_rules
    __args__['project'] = project
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getProjectApprovalRules:getProjectApprovalRules', __args__, opts=opts, typ=GetProjectApprovalRulesResult)
    return __ret__.apply(lambda __response__: GetProjectApprovalRulesResult(
        approval_rules=pulumi.get(__response__, 'approval_rules'),
        id=pulumi.get(__response__, 'id'),
        project=pulumi.get(__response__, 'project')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['BranchArgs', 'Branch']

@pulumi.input_type
class BranchArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[_builtins.str],
                 ref: pulumi.Input[_builtins.str],
                 keep_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Branch resource.
        :param pulumi.Input[_builtins.str] project: The ID or full path of the project which the branch is created against.
        :param pulumi.Input[_builtins.str] ref: The ref which the branch is created from.
        :param pulumi.Input[_builtins.bool] keep_on_destroy: Indicates whether the branch is kept once the resource destroyed (must be applied before a destroy).
        :param pulumi.Input[_builtins.str] name: The name for this branch.
        """
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "ref", ref)
        if keep_on_destroy is not None:
            pulumi.set(__self__, "keep_on_destroy", keep_on_destroy)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Input[_builtins.str]:
        """
        The ID or full path of the project which the branch is created against.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter
    def ref(self) -> pulumi.Input[_builtins.str]:
        """
        The ref which the branch is created from.
        """
        return pulumi.get(self, "ref")

    @ref.setter
    def ref(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "ref", value)

    @_builtins.property
    @pulumi.getter(name="keepOnDestroy")
    def keep_on_destroy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the branch is kept once the resource destroyed (must be applied before a destroy).
        """
        return pulumi.get(self, "keep_on_destroy")

    @keep_on_destroy.setter
    def keep_on_destroy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "keep_on_destroy", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name for this branch.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _BranchState:
    def __init__(__self__, *,
                 can_push: Optional[pulumi.Input[_builtins.bool]] = None,
                 commits: Optional[pulumi.Input[Sequence[pulumi.Input['BranchCommitArgs']]]] = None,
                 default: Optional[pulumi.Input[_builtins.bool]] = None,
                 developer_can_merge: Optional[pulumi.Input[_builtins.bool]] = None,
                 developer_can_push: Optional[pulumi.Input[_builtins.bool]] = None,
                 keep_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 merged: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 protected: Optional[pulumi.Input[_builtins.bool]] = None,
                 ref: Optional[pulumi.Input[_builtins.str]] = None,
                 web_url: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Branch resources.
        :param pulumi.Input[_builtins.bool] can_push: Bool, true if you can push to the branch.
        :param pulumi.Input[Sequence[pulumi.Input['BranchCommitArgs']]] commits: The commit associated with the branch ref.
        :param pulumi.Input[_builtins.bool] default: Bool, true if branch is the default branch for the project.
        :param pulumi.Input[_builtins.bool] developer_can_merge: Bool, true if developer level access allows to merge branch.
        :param pulumi.Input[_builtins.bool] developer_can_push: Bool, true if developer level access allows git push.
        :param pulumi.Input[_builtins.bool] keep_on_destroy: Indicates whether the branch is kept once the resource destroyed (must be applied before a destroy).
        :param pulumi.Input[_builtins.bool] merged: Bool, true if the branch has been merged into its parent.
        :param pulumi.Input[_builtins.str] name: The name for this branch.
        :param pulumi.Input[_builtins.str] project: The ID or full path of the project which the branch is created against.
        :param pulumi.Input[_builtins.bool] protected: Bool, true if branch has branch protection.
        :param pulumi.Input[_builtins.str] ref: The ref which the branch is created from.
        :param pulumi.Input[_builtins.str] web_url: The url of the created branch (https).
        """
        if can_push is not None:
            pulumi.set(__self__, "can_push", can_push)
        if commits is not None:
            pulumi.set(__self__, "commits", commits)
        if default is not None:
            pulumi.set(__self__, "default", default)
        if developer_can_merge is not None:
            pulumi.set(__self__, "developer_can_merge", developer_can_merge)
        if developer_can_push is not None:
            pulumi.set(__self__, "developer_can_push", developer_can_push)
        if keep_on_destroy is not None:
            pulumi.set(__self__, "keep_on_destroy", keep_on_destroy)
        if merged is not None:
            pulumi.set(__self__, "merged", merged)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if protected is not None:
            pulumi.set(__self__, "protected", protected)
        if ref is not None:
            pulumi.set(__self__, "ref", ref)
        if web_url is not None:
            pulumi.set(__self__, "web_url", web_url)

    @_builtins.property
    @pulumi.getter(name="canPush")
    def can_push(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Bool, true if you can push to the branch.
        """
        return pulumi.get(self, "can_push")

    @can_push.setter
    def can_push(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "can_push", value)

    @_builtins.property
    @pulumi.getter
    def commits(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BranchCommitArgs']]]]:
        """
        The commit associated with the branch ref.
        """
        return pulumi.get(self, "commits")

    @commits.setter
    def commits(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BranchCommitArgs']]]]):
        pulumi.set(self, "commits", value)

    @_builtins.property
    @pulumi.getter
    def default(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Bool, true if branch is the default branch for the project.
        """
        return pulumi.get(self, "default")

    @default.setter
    def default(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "default", value)

    @_builtins.property
    @pulumi.getter(name="developerCanMerge")
    def developer_can_merge(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Bool, true if developer level access allows to merge branch.
        """
        return pulumi.get(self, "developer_can_merge")

    @developer_can_merge.setter
    def developer_can_merge(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "developer_can_merge", value)

    @_builtins.property
    @pulumi.getter(name="developerCanPush")
    def developer_can_push(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Bool, true if developer level access allows git push.
        """
        return pulumi.get(self, "developer_can_push")

    @developer_can_push.setter
    def developer_can_push(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "developer_can_push", value)

    @_builtins.property
    @pulumi.getter(name="keepOnDestroy")
    def keep_on_destroy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the branch is kept once the resource destroyed (must be applied before a destroy).
        """
        return pulumi.get(self, "keep_on_destroy")

    @keep_on_destroy.setter
    def keep_on_destroy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "keep_on_destroy", value)

    @_builtins.property
    @pulumi.getter
    def merged(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Bool, true if the branch has been merged into its parent.
        """
        return pulumi.get(self, "merged")

    @merged.setter
    def merged(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "merged", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name for this branch.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID or full path of the project which the branch is created against.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter
    def protected(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Bool, true if branch has branch protection.
        """
        return pulumi.get(self, "protected")

    @protected.setter
    def protected(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "protected", value)

    @_builtins.property
    @pulumi.getter
    def ref(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ref which the branch is created from.
        """
        return pulumi.get(self, "ref")

    @ref.setter
    def ref(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ref", value)

    @_builtins.property
    @pulumi.getter(name="webUrl")
    def web_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The url of the created branch (https).
        """
        return pulumi.get(self, "web_url")

    @web_url.setter
    def web_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "web_url", value)


@pulumi.type_token("gitlab:index/branch:Branch")
class Branch(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 keep_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 ref: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        # Create a project for the branch to use
        example = gitlab.Project("example",
            name="example",
            description="An example project",
            namespace_id=example_gitlab_group["id"])
        example_branch = gitlab.Branch("example",
            name="example",
            ref="main",
            project=example.id)
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_branch`. For example:

        terraform

        import {

          to = gitlab_branch.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        Gitlab branches can be imported with a key composed of `<project_id>:<branch_name>`, e.g.

        ```sh
        $ pulumi import gitlab:index/branch:Branch example "12345:develop"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] keep_on_destroy: Indicates whether the branch is kept once the resource destroyed (must be applied before a destroy).
        :param pulumi.Input[_builtins.str] name: The name for this branch.
        :param pulumi.Input[_builtins.str] project: The ID or full path of the project which the branch is created against.
        :param pulumi.Input[_builtins.str] ref: The ref which the branch is created from.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BranchArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        # Create a project for the branch to use
        example = gitlab.Project("example",
            name="example",
            description="An example project",
            namespace_id=example_gitlab_group["id"])
        example_branch = gitlab.Branch("example",
            name="example",
            ref="main",
            project=example.id)
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_branch`. For example:

        terraform

        import {

          to = gitlab_branch.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        Gitlab branches can be imported with a key composed of `<project_id>:<branch_name>`, e.g.

        ```sh
        $ pulumi import gitlab:index/branch:Branch example "12345:develop"
        ```

        :param str resource_name: The name of the resource.
        :param BranchArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BranchArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 keep_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 ref: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BranchArgs.__new__(BranchArgs)

            __props__.__dict__["keep_on_destroy"] = keep_on_destroy
            __props__.__dict__["name"] = name
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if ref is None and not opts.urn:
                raise TypeError("Missing required property 'ref'")
            __props__.__dict__["ref"] = ref
            __props__.__dict__["can_push"] = None
            __props__.__dict__["commits"] = None
            __props__.__dict__["default"] = None
            __props__.__dict__["developer_can_merge"] = None
            __props__.__dict__["developer_can_push"] = None
            __props__.__dict__["merged"] = None
            __props__.__dict__["protected"] = None
            __props__.__dict__["web_url"] = None
        super(Branch, __self__).__init__(
            'gitlab:index/branch:Branch',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            can_push: Optional[pulumi.Input[_builtins.bool]] = None,
            commits: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BranchCommitArgs', 'BranchCommitArgsDict']]]]] = None,
            default: Optional[pulumi.Input[_builtins.bool]] = None,
            developer_can_merge: Optional[pulumi.Input[_builtins.bool]] = None,
            developer_can_push: Optional[pulumi.Input[_builtins.bool]] = None,
            keep_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
            merged: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None,
            protected: Optional[pulumi.Input[_builtins.bool]] = None,
            ref: Optional[pulumi.Input[_builtins.str]] = None,
            web_url: Optional[pulumi.Input[_builtins.str]] = None) -> 'Branch':
        """
        Get an existing Branch resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] can_push: Bool, true if you can push to the branch.
        :param pulumi.Input[Sequence[pulumi.Input[Union['BranchCommitArgs', 'BranchCommitArgsDict']]]] commits: The commit associated with the branch ref.
        :param pulumi.Input[_builtins.bool] default: Bool, true if branch is the default branch for the project.
        :param pulumi.Input[_builtins.bool] developer_can_merge: Bool, true if developer level access allows to merge branch.
        :param pulumi.Input[_builtins.bool] developer_can_push: Bool, true if developer level access allows git push.
        :param pulumi.Input[_builtins.bool] keep_on_destroy: Indicates whether the branch is kept once the resource destroyed (must be applied before a destroy).
        :param pulumi.Input[_builtins.bool] merged: Bool, true if the branch has been merged into its parent.
        :param pulumi.Input[_builtins.str] name: The name for this branch.
        :param pulumi.Input[_builtins.str] project: The ID or full path of the project which the branch is created against.
        :param pulumi.Input[_builtins.bool] protected: Bool, true if branch has branch protection.
        :param pulumi.Input[_builtins.str] ref: The ref which the branch is created from.
        :param pulumi.Input[_builtins.str] web_url: The url of the created branch (https).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BranchState.__new__(_BranchState)

        __props__.__dict__["can_push"] = can_push
        __props__.__dict__["commits"] = commits
        __props__.__dict__["default"] = default
        __props__.__dict__["developer_can_merge"] = developer_can_merge
        __props__.__dict__["developer_can_push"] = developer_can_push
        __props__.__dict__["keep_on_destroy"] = keep_on_destroy
        __props__.__dict__["merged"] = merged
        __props__.__dict__["name"] = name
        __props__.__dict__["project"] = project
        __props__.__dict__["protected"] = protected
        __props__.__dict__["ref"] = ref
        __props__.__dict__["web_url"] = web_url
        return Branch(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="canPush")
    def can_push(self) -> pulumi.Output[_builtins.bool]:
        """
        Bool, true if you can push to the branch.
        """
        return pulumi.get(self, "can_push")

    @_builtins.property
    @pulumi.getter
    def commits(self) -> pulumi.Output[Sequence['outputs.BranchCommit']]:
        """
        The commit associated with the branch ref.
        """
        return pulumi.get(self, "commits")

    @_builtins.property
    @pulumi.getter
    def default(self) -> pulumi.Output[_builtins.bool]:
        """
        Bool, true if branch is the default branch for the project.
        """
        return pulumi.get(self, "default")

    @_builtins.property
    @pulumi.getter(name="developerCanMerge")
    def developer_can_merge(self) -> pulumi.Output[_builtins.bool]:
        """
        Bool, true if developer level access allows to merge branch.
        """
        return pulumi.get(self, "developer_can_merge")

    @_builtins.property
    @pulumi.getter(name="developerCanPush")
    def developer_can_push(self) -> pulumi.Output[_builtins.bool]:
        """
        Bool, true if developer level access allows git push.
        """
        return pulumi.get(self, "developer_can_push")

    @_builtins.property
    @pulumi.getter(name="keepOnDestroy")
    def keep_on_destroy(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether the branch is kept once the resource destroyed (must be applied before a destroy).
        """
        return pulumi.get(self, "keep_on_destroy")

    @_builtins.property
    @pulumi.getter
    def merged(self) -> pulumi.Output[_builtins.bool]:
        """
        Bool, true if the branch has been merged into its parent.
        """
        return pulumi.get(self, "merged")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name for this branch.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[_builtins.str]:
        """
        The ID or full path of the project which the branch is created against.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter
    def protected(self) -> pulumi.Output[_builtins.bool]:
        """
        Bool, true if branch has branch protection.
        """
        return pulumi.get(self, "protected")

    @_builtins.property
    @pulumi.getter
    def ref(self) -> pulumi.Output[_builtins.str]:
        """
        The ref which the branch is created from.
        """
        return pulumi.get(self, "ref")

    @_builtins.property
    @pulumi.getter(name="webUrl")
    def web_url(self) -> pulumi.Output[_builtins.str]:
        """
        The url of the created branch (https).
        """
        return pulumi.get(self, "web_url")

